'-------------------------------------------------------------------------------
'-------------------------------------------------------------------------------
'-- stats.vbs
'-- 
'-- This script Generate the usage statistics for each IIS web site configured 
'-- on the computer using Analog and optionally ReportMagic. It can also 
'-- optionally delete the old log files
'--
'-- Author: Cdric Caron <Cedric.Caron@urbanet.ch>
'--
'-- History:
'--		08.06.2001: Version 1.1, use ExpandEnvironmentStrings to expand the environment variables
'--		14.05.2001: Version 1.0, Original release
'--              
'-------------------------------------------------------------------------------
'-------------------------------------------------------------------------------

verboseMode = True
statsFolder = "stats" 

analogCommand = "D:\Projects\stats\analog 5.0\analog.exe"
analogConfig = "D:\Projects\stats\analog 5.0\analog.cfg"
analogFilename = "index.html"
analogLogfile = "*.log"

reportmagicEnabled = True
reportmagicCommand = "D:\Projects\stats\rm2.05xw\rmagic.exe"
reportmagicConfig = "D:\Projects\stats\rm2.05xw\rmagic.ini"

logfiledeleteEnabled = True
logfiledeleteUnit = "m"
logfiledeleteDelay = 12

set objW3SVC = GetObject("IIS://LOCALHOST/W3SVC")
Set WshShell = WScript.CreateObject("WScript.Shell")

If (Err <> 0) Then
   WScript.Echo "Error " & Hex(Err.Number) & "(" & Err.Description & ") occurred."
Else
	For Each objSITE In objW3SVC
		If objSITE.class = "IIsWebServer" Then
			For Each objVDIR In objSITE
				If objVDIR.class = "IIsWebVirtualDir" Then
					Stats objSITE.ServerComment, objVDIR.Path, WshShell.ExpandEnvironmentStrings(objSITE.LogFileDirectory) & "\W3SVC" & objSITE.Name
				End If
			Next
		End If
	Next
End If

Sub Stats(name, sitepath, logpath)
	If verboseMode = True Then
		WScript.Echo "Generating statistics for: "
		WScript.Echo Chr(9) & "Name: " & name
		WScript.Echo Chr(9) & "Path: " & sitepath
		WScript.Echo Chr(9) & "Log: " & logpath
	End If
		
	' Create the destination folder
	Set fso = CreateObject("Scripting.FileSystemObject")
	If fso.FolderExists(sitepath & "\" & statsFolder) = False Then
		fso.CreateFolder(sitepath & "\" & statsFolder)
	End If
	
	' Delete old logfiles
	if logfiledeleteEnabled = True Then
		Set folder = fso.GetFolder(logpath)
		For Each logfile in folder.Files
			diff = DateDiff(logfiledeleteUnit, logfile.DateLastModified, Now)
			If diff > logfiledeleteDelay Then
				If verboseMode = True Then
					WScript.Echo logpath & "\" & logfile.Name & " (" & logfile.DateLastModified & " " & diff & ")"
				End If
				logfile.Delete
			End If
		Next
	End If

	'Start Analog
	if reportmagicEnabled = False Then
		param = " +O" & Chr(34) & sitepath & "\" & statsFolder & "\" & analogFilename & Chr(34)
	Else
		param = " +O" & Chr(34) & sitepath & "\" & statsFolder & "\analog.dat" & Chr(34)
		param = param & " +C"& Chr(34) & "OUTPUT COMPUTER" & Chr(34)
	End If
	param = param & " +C"& Chr(34) & "HOSTNAME '" & name & "'" & Chr(34)
	param = param & " -G +g"& Chr(34) & analogConfig & Chr(34)
	param = param & " " & Chr(34) & logpath & "\" & analogLogfile & Chr(34)
	cmd = Chr(34) & analogCommand & Chr(34) & param
	If verboseMode = True Then
		WScript.Echo cmd
	End If
	WshShell.Run cmd, 0, True

	'Start ReportMagic
	if reportmagicEnabled = True Then
		param = " -website_Title=" & Chr(34) & name & Chr(34)
		param = param & " -statistics_File_In=" & Chr(34) & sitepath & "\" & statsFolder & "\analog.dat" & Chr(34)
		param = param & " -statistics_Frame_File_Out=" & Chr(34) & sitepath & "\" & statsFolder & "\" & analogFilename & Chr(34)
		param = param & " -reports_File_Out=" & Chr(34) & sitepath & "\" & statsFolder & "\\"& Chr(34)
		param = param & " -navigation_File_Out=" & Chr(34) & sitepath & "\" & statsFolder & "\nav.html" & Chr(34)
		param = param & " " & Chr(34) & reportmagicConfig & Chr(34)
		cmd = Chr(34) & reportmagicCommand & Chr(34) & param
		If verboseMode = True Then
			WScript.Echo cmd
		End If
		WshShell.Run cmd, 0, True
	end If
End Sub
